==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/cdn/kotlin/inputs/CacheExpirationActionParametersArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.cdn.kotlin.inputs

import com.pulumi.azurenative.cdn.inputs.CacheExpirationActionParametersArgs.builder
import com.pulumi.azurenative.cdn.kotlin.enums.CacheBehavior
import com.pulumi.azurenative.cdn.kotlin.enums.CacheType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Defines the parameters for the cache expiration action.
 * @property cacheBehavior Caching behavior for the requests
 * @property cacheDuration The duration for which the content needs to be cached. Allowed format is [d&#46;]hh:mm:ss
 * @property cacheType The level at which the content needs to be cached.
 * @property typeName
 */
public data class CacheExpirationActionParametersArgs(
    public val cacheBehavior: Output<Either<String, CacheBehavior>>,
    public val cacheDuration: Output<String>? = null,
    public val cacheType: Output<Either<String, CacheType>>,
    public val typeName: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.cdn.inputs.CacheExpirationActionParametersArgs> {
    override fun toJava(): com.pulumi.azurenative.cdn.inputs.CacheExpirationActionParametersArgs =
        com.pulumi.azurenative.cdn.inputs.CacheExpirationActionParametersArgs.builder()
            .cacheBehavior(
                cacheBehavior.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .cacheDuration(cacheDuration?.applyValue({ args0 -> args0 }))
            .cacheType(
                cacheType.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .typeName(typeName.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [CacheExpirationActionParametersArgs].
 */
@PulumiTagMarker
public class CacheExpirationActionParametersArgsBuilder internal constructor() {
    private var cacheBehavior: Output<Either<String, CacheBehavior>>? = null

    private var cacheDuration: Output<String>? = null

    private var cacheType: Output<Either<String, CacheType>>? = null

    private var typeName: Output<String>? = null

    /**
     * @param value Caching behavior for the requests
     */
    @JvmName("mnqgvxwwbnptnmpy")
    public suspend fun cacheBehavior(`value`: Output<Either<String, CacheBehavior>>) {
        this.cacheBehavior = value
    }

    /**
     * @param value The duration for which the content needs to be cached. Allowed format is [d&#46;]hh:mm:ss
     */
    @JvmName("irxvmtefllqmbikt")
    public suspend fun cacheDuration(`value`: Output<String>) {
        this.cacheDuration = value
    }

    /**
     * @param value The level at which the content needs to be cached.
     */
    @JvmName("hkxobrlmryfxlmrd")
    public suspend fun cacheType(`value`: Output<Either<String, CacheType>>) {
        this.cacheType = value
    }

    /**
     * @param value
     */
    @JvmName("cjteoveqgidwlted")
    public suspend fun typeName(`value`: Output<String>) {
        this.typeName = value
    }

    /**
     * @param value Caching behavior for the requests
     */
    @JvmName("uxblthxavwqiwhjf")
    public suspend fun cacheBehavior(`value`: Either<String, CacheBehavior>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.cacheBehavior = mapped
    }

    /**
     * @param value Caching behavior for the requests
     */
    @JvmName("ovwelucmxntmeidg")
    public fun cacheBehavior(`value`: String) {
        val toBeMapped = Either.ofLeft<String, CacheBehavior>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.cacheBehavior = mapped
    }

    /**
     * @param value Caching behavior for the requests
     */
    @JvmName("hcmcvlqwtxhjnkst")
    public fun cacheBehavior(`value`: CacheBehavior) {
        val toBeMapped = Either.ofRight<String, CacheBehavior>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.cacheBehavior = mapped
    }

    /**
     * @param value The duration for which the content needs to be cached. Allowed format is [d&#46;]hh:mm:ss
     */
    @JvmName("nujhqsxcqpmahvvs")
    public suspend fun cacheDuration(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.cacheDuration = mapped
    }

    /**
     * @param value The level at which the content needs to be cached.
     */
    @JvmName("cpnpuyvvcqisrupd")
    public suspend fun cacheType(`value`: Either<String, CacheType>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.cacheType = mapped
    }

    /**
     * @param value The level at which the content needs to be cached.
     */
    @JvmName("hijtrdavqtaqhtxm")
    public fun cacheType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, CacheType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.cacheType = mapped
    }

    /**
     * @param value The level at which the content needs to be cached.
     */
    @JvmName("gckxpufvarufsjsk")
    public fun cacheType(`value`: CacheType) {
        val toBeMapped = Either.ofRight<String, CacheType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.cacheType = mapped
    }

    /**
     * @param value
     */
    @JvmName("qvnykknewlatstch")
    public suspend fun typeName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.typeName = mapped
    }

    internal fun build(): CacheExpirationActionParametersArgs = CacheExpirationActionParametersArgs(
        cacheBehavior = cacheBehavior ?: throw PulumiNullFieldException("cacheBehavior"),
        cacheDuration = cacheDuration,
        cacheType = cacheType ?: throw PulumiNullFieldException("cacheType"),
        typeName = typeName ?: throw PulumiNullFieldException("typeName"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/cdn/kotlin/inputs/CacheExpirationActionParametersArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.cdn.kotlin.inputs

import com.pulumi.azurenative.cdn.inputs.CacheExpirationActionParametersArgs.builder
import com.pulumi.azurenative.cdn.kotlin.enums.CacheBehavior
import com.pulumi.azurenative.cdn.kotlin.enums.CacheType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Defines the parameters for the cache expiration action.
 * @property cacheBehavior Caching behavior for the requests
 * @property cacheDuration The duration for which the content needs to be cached. Allowed format is [d&#46;]hh:mm:ss
 * @property cacheType The level at which the content needs to be cached.
 * @property typeName
 */
public data class CacheExpirationActionParametersArgs(
    public val cacheBehavior: Output<Either<String, CacheBehavior>>,
    public val cacheDuration: Output<String>? = null,
    public val cacheType: Output<Either<String, CacheType>>,
    public val typeName: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.cdn.inputs.CacheExpirationActionParametersArgs> {
    override fun toJava(): com.pulumi.azurenative.cdn.inputs.CacheExpirationActionParametersArgs =
        com.pulumi.azurenative.cdn.inputs.CacheExpirationActionParametersArgs.builder()
            .cacheBehavior(
                cacheBehavior.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .cacheDuration(cacheDuration?.applyValue({ args0 -> args0 }))
            .cacheType(
                cacheType.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .typeName(typeName.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [CacheExpirationActionParametersArgs].
 */
@PulumiTagMarker
public class CacheExpirationActionParametersArgsBuilder internal constructor() {
    private var cacheBehavior: Output<Either<String, CacheBehavior>>? = null

    private var cacheDuration: Output<String>? = null

    private var cacheType: Output<Either<String, CacheType>>? = null

    private var typeName: Output<String>? = null

    /**
     * @param value Caching behavior for the requests
     */
    @JvmName("guxyqdcrcmmtskvm")
    public suspend fun cacheBehavior(`value`: Output<Either<String, CacheBehavior>>) {
        this.cacheBehavior = value
    }

    /**
     * @param value The duration for which the content needs to be cached. Allowed format is [d&#46;]hh:mm:ss
     */
    @JvmName("wvggviekmqlimuli")
    public suspend fun cacheDuration(`value`: Output<String>) {
        this.cacheDuration = value
    }

    /**
     * @param value The level at which the content needs to be cached.
     */
    @JvmName("wvpcrpagyunqqbgn")
    public suspend fun cacheType(`value`: Output<Either<String, CacheType>>) {
        this.cacheType = value
    }

    /**
     * @param value
     */
    @JvmName("orpvmdwbiqrnuywd")
    public suspend fun typeName(`value`: Output<String>) {
        this.typeName = value
    }

    /**
     * @param value Caching behavior for the requests
     */
    @JvmName("kmdfktmatppkpbqa")
    public suspend fun cacheBehavior(`value`: Either<String, CacheBehavior>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.cacheBehavior = mapped
    }

    /**
     * @param value Caching behavior for the requests
     */
    @JvmName("quypeojbgwrtbxcb")
    public fun cacheBehavior(`value`: String) {
        val toBeMapped = Either.ofLeft<String, CacheBehavior>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.cacheBehavior = mapped
    }

    /**
     * @param value Caching behavior for the requests
     */
    @JvmName("nrolrhpowcugxmtf")
    public fun cacheBehavior(`value`: CacheBehavior) {
        val toBeMapped = Either.ofRight<String, CacheBehavior>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.cacheBehavior = mapped
    }

    /**
     * @param value The duration for which the content needs to be cached. Allowed format is [d&#46;]hh:mm:ss
     */
    @JvmName("xccxwtjdndnueicm")
    public suspend fun cacheDuration(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.cacheDuration = mapped
    }

    /**
     * @param value The level at which the content needs to be cached.
     */
    @JvmName("oemfowanrfxnupst")
    public suspend fun cacheType(`value`: Either<String, CacheType>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.cacheType = mapped
    }

    /**
     * @param value The level at which the content needs to be cached.
     */
    @JvmName("mexeepgiucajvgmb")
    public fun cacheType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, CacheType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.cacheType = mapped
    }

    /**
     * @param value The level at which the content needs to be cached.
     */
    @JvmName("rmnsbfsdihgkjbuu")
    public fun cacheType(`value`: CacheType) {
        val toBeMapped = Either.ofRight<String, CacheType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.cacheType = mapped
    }

    /**
     * @param value
     */
    @JvmName("wlrmxyecsjdnmlyn")
    public suspend fun typeName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.typeName = mapped
    }

    internal fun build(): CacheExpirationActionParametersArgs = CacheExpirationActionParametersArgs(
        cacheBehavior = cacheBehavior ?: throw PulumiNullFieldException("cacheBehavior"),
        cacheDuration = cacheDuration,
        cacheType = cacheType ?: throw PulumiNullFieldException("cacheType"),
        typeName = typeName ?: throw PulumiNullFieldException("typeName"),
    )
}
